Author:

* [Anthony Brown (Leiden Observatory)](http://www.strw.leidenuniv.nl/~brown)

Gaia performance modelling from:

* [Gaia Science Performance pages](https://www.cosmos.esa.int/web/gaia/science-performance)

Direct contributions to the code base:

* [John Helly](https://github.com/jchelly)
* [Javier Olivares](https://github.com/olivares-j)
* [Tom Callingham](https://github.com/TomCallingham)
* [Henry Leung](https://github.com/henrysky)
* [Morgan Fouesneau](https://github.com/mfouesneau)
* [Johannes Sahlmann](https://github.com/Johannes-Sahlmann)

Comments, corrections & suggestions:
